@@ -10,7 +10,7 @@ Net::Vitelity - Interface to Vitelity API
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $AUTOLOAD;
 
@@ -22,6 +22,7 @@ our $AUTOLOAD;
                                        'login'   => $your_login,
                                        'pass'    => $your_pass,
                                        'apitype' => 'api', #api, fax or lnp
+                                       'debug'   => 0,
                                      );
 
 =head1 METHODS
@@ -39,6 +40,7 @@ sub new {
     die "missing user and/or password" unless defined $data{'login'} && defined $data{'pass'};
     my $self = { 'login' => $data{'login'}, 'pass' => $data{'pass'} };
     $self->{apitype} = $data{'apitype'} ? $data{'apitype'} : 'api';
+    $self->{debug} = $data{'debug'} ? 1 : 0;
     bless $self, $class;
     return $self;
 }
@@ -62,6 +64,12 @@ sub AUTOLOAD {
   $url = $URL_FAX if $self->{apitype} eq 'fax';
   $url = $URL_LNP if $self->{apitype} eq 'lnp';
 
+  if ( $self->{debug} ) {
+    warn "Vitelity $cmd ($url)\n";
+    my %hash = @_;
+    warn "  $_: $hash{$_}\n" foreach keys %hash;
+  }
+
   my $response = $ua->post($url, {
                     login => $self->{login}, 
                     pass  => $self->{pass},
